<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Calendar directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2010-2016.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	G. Cronkright
Custom Field Type:
	approval track checkbox
Name:
	approval_track_checkboxes_render.cfm
Summary:
	A custom checkbox field that also captures the dataTime stamp and the CS UserID and copies
	those values to other fields in the form. Field IDs can be set in the props for the other 
	text or hidden fields in the same form.
ADF Requirements:
	date_1_0
	scripts_1_0
History:
	2011-07-28 - GAC - Created
	2012-01-27 - GAC - Added update for CS 6.x for field permissions / backwards compatible for CS 5.x
	2015-05-27 - DRM - Updates for cs 10.0
	2015-09-10 - GAC - Replace the .attr("checked") with is(':checked') for status of checkbox
	2016-02-24 - DRM - Resource detection support
--->
<cfcomponent displayName="CalendarTimePicker Render" extends="ADF.extensions.customfields.adf-form-field-renderer-base">

<cffunction name="renderControl" returntype="void" access="public">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">

	<cfscript>
		// the param structure which will hold all of the fields from the props dialog
		var params = setDefaultParameters(argumentCollection=arguments);

		var readOnly = (arguments.displayMode == "readonly");

		// Get the Now() dateTimeStamp formated for CommonSpot
		var csDateTimeStamp = application.ptCalendar.date.csDateFormat(Now(),Now());

		var tempFieldsType = "hidden"; //default: 'hidden' option: 'text'
		var cftDebug = false; // default: false, for debugging set to TRUE
		if ( cftDebug )
			tempFieldsType = "text";

		// Check the default value
		if ( len(arguments.value) LTE 0 )
		{
			arguments.value = params.uncheckedVal; //'no'
			// If defaulted to checked
			if ( params.defaultVal EQ "yes" )
				arguments.value = params.checkedVal; //'yes'
			else if ( params.defaultVal EQ "denied" AND len(params.deniedVal) )
				arguments.value = params.deniedVal; //'denied'
		}
	</cfscript>

	<cfoutput>
		<script>
			jQuery(function()
			{
				jQuery.radioCheckboxGroup("#arguments.fieldName#_checkbox");


				// Set the value of the checkbox based on the Stored field value
				if ( jQuery('input[name=#arguments.fieldName#]').val() == '#params.checkedVal#' ) {
					jQuery('###params.fldID#_checkbox_approved').attr('checked', 'checked');
				}
			<cfif len(params.deniedVal)>
				else if ( jQuery('input[name=#arguments.fieldName#]').val() == '#params.deniedVal#' ) {
					jQuery('###params.fldID#_checkbox_denied').attr('checked', 'checked');
				}
			</cfif>
				else {
					jQuery('###params.fldID#_checkbox_approved').removeAttr('checked');
				<cfif len(params.deniedVal)>
					jQuery('###params.fldID#_checkbox_denied').removeAttr('checked');
				</cfif>
				}

				<cfif !readOnly>
				// On Checkbox (or Checkboxes) Change Action
				jQuery('input[name=#arguments.fieldName#_checkbox]').change(function()
				{
					var clickedID = jQuery(this).attr("id");
					var clickedValue = jQuery(this).val();
					if ( jQuery("##" + clickedID).is(':checked') && clickedValue == 1 ) 
					{
						currVal = "#params.checkedVal#";
					}
					<cfif len(params.deniedVal)>
					else if ( jQuery("##" + clickedID).is(':checked') && clickedValue == 0 ) 
					{
						currVal = "#params.deniedVal#";
					}
					</cfif>
					else 
					{
						currVal = "#params.uncheckedVal#";
					}

					// Set the field value to be stored for this field
					jQuery('input[name=#arguments.fieldName#]').val(currVal);

					<cfif len(params.fldUserID)>
					// Call the Update ApprovalUserID function
					updateApprovalUserID_#arguments.fieldName#();
					</cfif>
					<cfif len(params.fldDateTime)>
					// Call the Update Approved DateTime function
					updateApprovedDateTime_#arguments.fieldName#();
					</cfif>
					<cfif len(params.fldDenialMsg)>
					// Call the showHideDenialMsg function
					showHideDenialMsg_#arguments.fieldName#();
					</cfif>
				});
				</cfif>

				// If we have a fldDenialMsg Binding and the Denied Checkbox is checked show the Denial Message Field
				<cfif len(params.fldDenialMsg)>
					showHideDenialMsg_#arguments.fieldName#();
				</cfif>
			});

			// Set the Approved UserID if the UserID Field ID binding is set
			<cfif len(params.fldUserID)>
			function updateApprovalUserID_#arguments.fieldName#() {
				var apprvlUserID = jQuery("###params.fldID#_userid").val();
				jQuery("###params.fldUserID#").val(apprvlUserID);
			}
			</cfif>

			// Set the Approved DateTime Stamp if the DateTime Field ID binding is set
			<cfif len(params.fldDateTime)>
			function updateApprovedDateTime_#arguments.fieldName#(){
				var apprvlDateTime = jQuery("###params.fldID#_datetime").val();
				jQuery("###params.fldDateTime#").val(apprvlDateTime);
			}
			</cfif>

			// Set the Denial Msg Field visibility if the Denial Msg Field ID binding is set
			<cfif len(params.fldDenialMsg)>
			function showHideDenialMsg_#arguments.fieldName#()
			{
				var deniedCheckboxStatus = jQuery('###params.fldID#_checkbox_denied').is(':checked');
				var storedFieldValue = jQuery('input[name=#arguments.fieldName#]').val();
				// if the deniedCheckboxStatus is true show the Denial Msg Field
				var show = (deniedCheckboxStatus && storedFieldValue == '#params.deniedVal#');

				adf.formUtils.showHideCSFieldByDomId('#params.fldDenialMsg#', show);

				if (!show)
					jQuery("###params.fldDenialMsg#").val("");
					
				apprvResizeWindow();
			}

			function apprvResizeWindow()
			{
				setTimeout(function() {ResizeWindow();}, 0);
			}
			</cfif>
		</script>

	<cfscript>
		// done this way to avoid whitespace and/or a non-clickable area between checkbox and text
		labelStart = "<label>";
		approvedLabelEnd = "#params.approvedLabel#</label>";
		deniedLabelEnd = "#params.deniedLabel#</label>";
	</cfscript>

	<div id="#arguments.fieldName#_renderCheckbox">
		#labelStart#<input type='checkbox' name='#arguments.fieldName#_checkbox' id='#params.fldID#_checkbox_approved'<cfif len(params.fldClass)> class="#params.fldClass#"</cfif> value='1' <cfif readOnly>readonly</cfif>>#approvedLabelEnd#
		<cfif len(params.deniedVal)>
			&nbsp;&nbsp;&nbsp;
			#labelStart#<input type='checkbox' name='#arguments.fieldName#_checkbox' id='#params.fldID#_checkbox_denied'<cfif len(params.fldClass)> class="#params.fldClass#"</cfif> value='0' <cfif readOnly>readonly</cfif>>#deniedLabelEnd#
		</cfif>
	</div>
	<!--- hidden field to store the value --->
	<cfif cftDebug>Stored: </cfif><input type='#tempFieldsType#' name='#arguments.fieldName#' id='#params.fldID#' value='#arguments.value#'><cfif cftDebug><br/></cfif>
	<cfif cftDebug>DateTime: </cfif><input type='#tempFieldsType#' name='#arguments.fieldName#_datetime' id='#params.fldID#_datetime' value='#csDateTimeStamp#'><cfif cftDebug><br/></cfif>
	<cfif cftDebug>UserID: </cfif><input type='#tempFieldsType#' name='#arguments.fieldName#_userid' id='#params.fldID#_userid' value='#request.user.id#'><cfif cftDebug><br/></cfif>
	<!--- <cfif cftDebug>Status: </cfif><input type='#tempFieldsType#' name='#arguments.fieldName#_status' id='#params.fldID#_status' value=''><cfif cftDebug><br/></cfif> --->
	</cfoutput>
</cffunction>


<cfscript>
	private struct function setDefaultParameters(required string fieldName, required string fieldDomID, required string value)
	{
		var params = Duplicate(arguments.parameters);

		if ( NOT StructKeyExists(params, "fldClass") )
			params.fldClass = "";
		else
			params.fldClass = trim(params.fldClass);

		if ( NOT StructKeyExists(params, "fldName") )
			params.fldName = arguments.fieldName;
		else if ( len(trim(params.fldName)) EQ 0 )
			params.fldName = ReplaceNoCase(params.fieldName,'fic_','');

		// Set the value that is stored when the checkbox is checked
		if ( NOT StructKeyExists(params, "checkedVal") )
			params.checkedVal = "yes";
		
		// Set the value that is stored when the checkbox is checked
		if ( NOT StructKeyExists(params, "uncheckedVal") )
			params.uncheckedVal = "no";

		// FieldID used to capture the Approval dateTime stamp
		if( not structKeyExists(params, "fldDateTime") )
			params.fldDateTime = "";
		else
			params.fldDateTime = trim(params.fldDateTime);
		
		// FieldID used to capture the Approver userID
		if( not structKeyExists(params, "fldUserID") )
			params.fldUserID = "";
		else
			params.fldUserID = trim(params.fldUserID);
		
		// FieldID of the Denial Reason Text Area field
		if( not structKeyExists(params, "fldDenialMsg") )
			params.fldDenialMsg = "";
		else
			params.fldDenialMsg = trim(params.fldDenialMsg);

		// FieldID of the Denial Value Text Area field
		if( not structKeyExists(params, "deniedVal") )
			params.deniedVal = "";
		else
			params.deniedVal = trim(params.deniedVal);;

		// FieldID of the Denial Checkbox Label
		if( not structKeyExists(params, "deniedLabel") OR len(trim(params.deniedLabel)) EQ 0 )
			params.deniedLabel = "Denied";
		else
			params.deniedLabel = trim(params.deniedLabel);
		
		// FieldID of the Approved Checkbox Value
		if( not structKeyExists(params, "approvedLabel") )
			params.approvedLabel = "";
		else
			params.approvedLabel = trim(params.approvedLabel);

		// Set the DEFAULT Approved Label if a Denied Label has been set but no Approved Label
		if ( len(params.deniedVal) AND len(params.deniedLabel) AND len(params.approvedLabel) EQ 0 )
			params.approvedLabel = "Approved";

		// Set the field ID from the field name
		params.fldID = trim(params.fldName);

		return params;
	}

	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery,jQueryCheckboxes,ADFcsFormUtilities");
	}
	public string function loadResourceDependencies()
	{
		application.ptCalendar.scripts.loadJQuery();
		application.ptCalendar.scripts.loadJQueryCheckboxes();
		Server.CommonSpot.udf.resources.loadResources("ADFcsFormUtilities");
	}
</cfscript>

</cfcomponent>