<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Calendar directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2010-2016.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	G. Cronkright 
Custom Field Type:
	Calendar Organization Radio Buttons Field
Name:
	calendar_org_radio_buttons_props.cfm
Summary:
	Custom Field to select Organizations from Radio Button list
	with a select all option. Also can be bound to the event category 
	checkbox field to display category checkbox options based on the selected
	organization
History:
	2011-08-18 - GAC - Created
	2013-09-19 - GAC - Added a renderField option to allow the field to be hidden
	2014-09-25 - GAC - Removed deprecated doLabel and jsLabelUpdater js calls
					 	  - Added the fieldVersion variable
	2015-05-28 - DRM - Bumped field version
						  - Removed obsolete props
	2016-02-25 - DRM - Resource detection exit
						  - Remove force scripts UI
						  - Bump field version
--->

<!--- if this module loads resources, do it here.. --->
<cfscript>
	application.ptCalendar.scripts.loadJQuery(noConflict=true);
</cfscript>

<!--- ... then exit if all we're doing is detecting required resources --->
<cfif Request.RenderState.RenderMode EQ "getResources">
  <cfexit>
</cfif>


<cfscript>
	// Variable for the version of the field - Display in Props UI.
	fieldVersion = "2.0.1";
	
	// initialize some of the attributes variables
	typeid = attributes.typeid;
	prefix = attributes.prefix;
	formname = attributes.formname;
	currentValues = attributes.currentValues;

	// Setup the default values
	defaultValues = StructNew();
	defaultValues.orgFieldID = "";
	defaultValues.catFieldID = "";
	defaultValues.useOnlyAciveOrgs = "1";
	defaultValues.useALLoption = "1";
	defaultValues.allOptionLabel = ""; // Default is blank since the App with use a value from the Config: All Organizations
	defaultValues.allOptionValueType = "useconfig"; // 'none', 'all', 'custom' or 'useconfig'
	defaultValues.allOptionValue = "";	
	defaultValues.defaultOptionType = "useconfig"; // 'none', 'all', 'record' or 'useconfig'
	defaultValues.defaultOptionValue = "";
	defaultValues.optionSortField = "useconfig";
	//defaultValues.optionSortField = "name"; // name or ordinal
	defaultValues.renderField = "yes";
	
	// This will override the current values with the default values.
	// In normal use this should not need to be modified.
	defaultValueArray = StructKeyArray(defaultValues);
	for(i=1;i<=ArrayLen(defaultValueArray);i++){
		// If there is a default value to exists in the current values
		//	AND the current value is an empty string
		//	OR the default value does not exist in the current values
		if( ( StructKeyExists(currentValues, defaultValueArray[i]) 
				AND (NOT LEN(currentValues[defaultValueArray[i]])) )
				OR (NOT StructKeyExists(currentValues, defaultValueArray[i])) ){
			currentValues[defaultValueArray[i]] = defaultValues[defaultValueArray[i]];
		}
	}

	// Get the Calendar ORG Data
	orgData = application.ptCalendar.calOrganizationsDAO.getCalOrganizations();
</cfscript>

<cfoutput>
	<script language="JavaScript" type="text/javascript">
		// register the fields with global props object
		fieldProperties['#typeid#'].paramFields = '#prefix#orgFieldID,#prefix#catFieldID,#prefix#useOnlyAciveOrgs,#prefix#useALLoption,#prefix#allOptionLabel,#prefix#allOptionValue,#prefix#defaultOptionType,#prefix#defaultOptionValue,#prefix#optionSortField,#prefix#renderField';

		jQuery(document).ready(function(){
			// Default Options - click event
			jQuery("input[name='#prefix#defaultOptionType']").change(function(){
				if ( jQuery("input[name='#prefix#defaultOptionType']:checked").val() == 'custom' ){
					jQuery("###prefix#defaultOptionValueRecord").val("");
				}
				else if ( jQuery("input[name='#prefix#defaultOptionType']:checked").val() == 'record' ){
					jQuery("###prefix#defaultOptionValueCustom").val("");
				}
				else {
					jQuery("###prefix#defaultOptionValueRecord").val("");
					jQuery("###prefix#defaultOptionValueCustom").val("");
					jQuery("###prefix#defaultOptionValue").val("");
				}
			});	
			
			// Move the Entered Custom Value to the hidden field
			jQuery("input[name='#prefix#defaultOptionValueCustom']").bind('keyup keypress blur', function() {
				var inputVal = jQuery(this).val();
				// put the entered value into the hidden field
				jQuery("input[name='#prefix#defaultOptionValue']").val(inputVal);
			});
			
			// Move the Selected Record Value to the hidden field
			jQuery("select[name='#prefix#defaultOptionValueRecord']").change(function(){
				var selectedVal = jQuery(this).val();
				// put the selected value into the hidden field
				jQuery("input[name='#prefix#defaultOptionValue']").val(selectedVal);
			});
		});
	</script>

	<input type="hidden" id="#prefix#allOptionValue" name="#prefix#allOptionValue" value="#currentValues.allOptionValue#" />
	<table>
		<tr>
			<td colspan="2" class="cs_dlgLabelSmall">Organization and Category Field Bindings:</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Organization Field ID:</td>
			<td class="cs_dlgLabelSmall" nowrap="nowrap">
				<input type="text" name="#prefix#orgFieldID" id="#prefix#orgFieldID" value="#currentValues.orgFieldID#"size="40" />
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Category Field ID:</td>
			<td class="cs_dlgLabelSmall" nowrap="nowrap">
				<input type="text" name="#prefix#catFieldID" id="#prefix#catFieldID" value="#currentValues.catFieldID#" size="40" />
			</td>
		</tr>
		<tr>
			<td colspan="2" class="cs_dlgLabelSmall"><hr></td>
		</tr>
		<!--- <tr>
			<td colspan="2" class="cs_dlgLabelSmall"></td>
		</tr> --->
		<tr>
			<td class="cs_dlgLabelSmall">Display Only Active Organizations:</td>
			<td class="cs_dlgLabelSmall" nowrap="nowrap">
				Yes&nbsp;<input type="radio" id="#prefix#useOnlyAciveOrgsYes" name="#prefix#useOnlyAciveOrgs" value="1"<cfif currentValues.useOnlyAciveOrgs EQ "1"> checked="checked"</cfif>>&nbsp;&nbsp;&nbsp;
				No&nbsp;<input type="radio" id="#prefix#useOnlyAciveOrgsNo" name="#prefix#useOnlyAciveOrgs" value="0"<cfif currentValues.useOnlyAciveOrgs EQ "0"> checked="checked"</cfif>><br />
			</td>
		</tr>
		<tr>
			<td colspan="2" class="cs_dlgLabelSmall"><hr></td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Add an 'All' Option Radio Button:</td>
			<td class="cs_dlgLabelSmall" nowrap="nowrap">
				Yes&nbsp;<input type="radio" id="#prefix#useALLoptionYes" name="#prefix#useALLoption" value="1"<cfif currentValues.useALLoption EQ "1"> checked="checked"</cfif>>&nbsp;&nbsp;&nbsp;
				No&nbsp;<input type="radio" id="#prefix#useALLoptionNo" name="#prefix#useALLoption" value="0"<cfif currentValues.useALLoption EQ "0"> checked="checked"</cfif>><br />
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">'All' Option Label:</td>
			<td class="cs_dlgLabelSmall" nowrap="nowrap">
				<input type="text" name="#prefix#allOptionLabel" id="#prefix#allOptionLabel" value="#currentValues.allOptionLabel#" size="40" />
				<br/><span>Leave blank to use label from App config value</span>
			</td>
		</tr>

		<tr>
			<td colspan="2" class="cs_dlgLabelSmall"><hr></td>
		</tr> 
		
		<!--- // SELECT A DEFAULT OPTION TYPE AND A DEFAULT OPTION VALUE --->
		<tr>
			<td class="cs_dlgLabelSmall" valign="top">Default Selected Option:</td>
			<td class="cs_dlgLabelSmall" nowrap="nowrap">
				<input type="radio" id="#prefix#defaultOptionTypeNone" name="#prefix#defaultOptionType" value="none"<cfif currentValues.defaultOptionType EQ "none"> checked="checked"</cfif>>No Value [""]<br/>
				<input type="radio" id="#prefix#defaultOptionTypeAll" name="#prefix#defaultOptionType" value="all"<cfif currentValues.defaultOptionType EQ "all"> checked="checked"</cfif>>All Organzations<br/>
				<input type="radio" id="#prefix#defaultOptionTypeRecord" name="#prefix#defaultOptionType" value="record"<cfif currentValues.defaultOptionType EQ "record"> checked="checked"</cfif>>Manual Selection<br/>
				&nbsp; &nbsp; &nbsp; <select name="#prefix#defaultOptionValueRecord" id="#prefix#defaultOptionValueRecord"> <!--- //only allow 1 default value (right now) - multiple="multiple" size="5" --->
					<option value=""<cfif currentValues.defaultOptionValue EQ ""> selected="selected"</cfif>>-- select --</option>
					<cfif ArrayLen(orgData)>
						<cfloop from="1" to="#ArrayLen(orgData)#" index="itm">
							<option value="#orgData[itm].values.uniqueID#"<cfif currentValues.defaultOptionType EQ "record" AND ListFindNoCase(currentValues.defaultOptionValue,orgData[itm].values.uniqueID)> selected="selected"</cfif>>#orgData[itm].values.name#</option>
						</cfloop>
					</cfif>
				</select><br>
				<input type="radio" id="#prefix#defaultOptionTypeUseConfig" name="#prefix#defaultOptionType" value="useconfig"<cfif currentValues.defaultOptionType EQ "useconfig"> checked="checked"</cfif>>Use Value From App Config<br/>
				<input type="hidden" name="#prefix#defaultOptionValue" id="#prefix#defaultOptionValue" value="#currentValues.defaultOptionValue#" />
			</td>
		</tr>

		<!--- // // Allow the Config value to be overriden via the Field Props (for now!) --->
		<tr>
			<td colspan="2" class="cs_dlgLabelSmall"><hr></td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Sort Field:</td>
			<td class="cs_dlgLabelSmall" nowrap="nowrap">
				Name (A-Z)&nbsp;<input type="radio" id="#prefix#optionSortFieldName" name="#prefix#optionSortField" value="name"<cfif currentValues.optionSortField EQ "name"> checked="checked"</cfif>>&nbsp;&nbsp;&nbsp;
				Ordinal (0-9999)&nbsp;<input type="radio" id="#prefix#optionSortFieldOrdinal" name="#prefix#optionSortField" value="ordinal"<cfif currentValues.optionSortField EQ "ordinal"> checked="checked"</cfif>>&nbsp;&nbsp;&nbsp;
				Use App Config&nbsp;<input type="radio" id="#prefix#optionSortFieldOrdinal" name="#prefix#optionSortField" value="useconfig"<cfif currentValues.optionSortField EQ "useconfig"> checked="checked"</cfif>><br />
			</td>
		</tr> 
		<!--- <input type="hidden" id="#prefix#optionSortField" name="#prefix#optionSortField" value="#currentValues.optionSortField#"> --->
		
		<tr>
			<td colspan="2" class="cs_dlgLabelSmall"><hr></td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Field Display Type:</td>
			<td class="cs_dlgLabelSmall">
				<input type="radio" name="#prefix#renderField" id="#prefix#renderField" value="yes" <cfif currentValues.renderField eq 'yes'>checked</cfif>>Visible
				<input type="radio" name="#prefix#renderField" id="#prefix#renderField" value="no" <cfif currentValues.renderField eq 'no'>checked</cfif>>Hidden
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall" colspan="2" style="font-size:7pt;">
				<hr />
				ADF Custom Field v#fieldVersion#
			</td>
		</tr>
	</table>
</cfoutput>