<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Calendar directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2010-2016.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->
<!---
/* *************************************************************** */
Author:
	PaperThin, Inc.
	G. Cronkright
Custom Field Type:
	Calendar Organization Radio Buttons Field
Name:
	calendar_org_radio_buttons_render.cfm
Summary:
	Custom Field to select Organizations from Radio Button list
	with a select all option. Also can be bound to the event category
	checkbox field to display category checkbox options based on the selected
	organization
ADF Requirements:
	scripts_1_0
	ptCalendar.calOrganizationsDAO
History:
	2011-08-18 - GAC - Created
	2013-09-19 - GAC - Added a renderField option to allow the field to be hidden
	2015-06-09 - DRM - Converted to cfc for ADF 2.0/CommonSpot 10
						  - Much cruft and confusion removal
						  - One notable change is that it always gets the value of the All Organizations radio from the app
	2015-06-19 - DRM - Fix issue with renderLabelWrapper when renderField doesn't exist in params
							 Default we set elsewhere doesn't make it through to there, have to check if it exists locally
	2016-02-25 - DRM - Resource detection support
--->
<cfcomponent extends="ADF.extensions.customfields.adf-form-field-renderer-base" output="no">

<cffunction name="renderControl" access="public" returnType="void">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfargument name="isRequired" type="boolean" required="yes">

	<cfscript>
		// the param structure which will hold all of the fields from the props dialog
		var params = setParamDefaults(arguments.fieldName, arguments.parameters);
		var orgData = "";
		var allOrgsOptionValue = application.ptCalendar.getAllOrganizationsValue();
		var x = 0;

		arguments.value = trim(arguments.value);
	
		// Get Organization ID and Names Structure to build the radio button list
		if ( len(params.optionSortField) )
			orgData = application.ptCalendar.calOrganizationsDAO.getCalOrgIDandNameArray(activeOnly=params.useOnlyAciveOrgs,sortField=params.optionSortField);
		else
			orgData = application.ptCalendar.calOrganizationsDAO.getCalOrgIDandNameArray(activeOnly=params.useOnlyAciveOrgs);
	
		// Set the Label from config of the All Orgs option is blank
		if ( len(params.allOptionLabel) EQ 0 ) {
			params.allOptionLabel = application.ptCalendar.getAllOrganizationsLabel();
		}
	
		// Set the Default Value to be selected if the arguments.value has not been set
		if ( len(arguments.value) EQ 0 ) {
			if ( params.defaultOptionType EQ "record" ) {
				arguments.value = params.defaultOptionValue;
			}
			else if ( params.defaultOptionType EQ "all" ) {
				arguments.value = allOrgsOptionValue;
			}
			else if ( params.defaultOptionType EQ "useconfig" ) {
				arguments.value = application.ptCalendar.getAllOrganizationsDefaultValue();
			}
			// aka. defaultOptionType = none
			else {
				arguments.value = "";
			}
		}
		else {
			// Select the item that matches the arguments.value
		}

		// Check the arguments.value matches the All Orgs Value
		// - If it does set it 'no value' to pass the the category checkbox field
		currentSelectedOrgValue = arguments.value;
		if (len(params.catFieldID) && arguments.value == allOrgsOptionValue)
			currentSelectedOrgValue = "";
	</cfscript>
	
	<cfoutput>
	<cfif len(params.catFieldID)>
		<script>
			jQuery(function(){

			/* TRIGGER THE CATEGORIES TO LOAD FOR THE SELECTED ORG */
				<cfif len(arguments.value)>
					// loadCategories_#params.catFieldID#() - JS function in the Event Category Checkboxes CFT
					loadCategories_#params.catFieldID#('#currentSelectedOrgValue#');
				<cfelse>
					// Show a 'Selected an Org' message in the Cat Field if no Org has be selected/
					// - 'No Org Selected' msg JS function in the Event Category Checkboxes CFT
					loadCategoriesNoneSelectedMsg_#params.catFieldID#();
				</cfif>

			// On the Click of a Radio Button add the Value to the hidden field
			// - If Binding exists... load the related CATEGORIES for this ORG
			jQuery("input[name='#arguments.fieldName#']").click(function(){
				var catParentItem = '';
				var selectedItem = jQuery("input[name='#arguments.fieldName#']:checked").val();
				if ( selectedItem == '#allOrgsOptionValue#' )
					catParentItem = '';
				else
					catParentItem = selectedItem;

				// On click load the categories for the selected organization (and clear old selections)
				// loadCategories_#params.catFieldID#() - JS function in the Event Category Checkboxes CFT
				// - with loadCurrentSelections set to false
				loadCategories_#params.catFieldID#(catParentItem,false);
			});
		});
	</script>
	</cfif>

	<div id="#params.orgFieldID#_orgOptionsBox"<cfif params.renderField EQ "no"> style="display:none;"</cfif>>
		<cfif params.useALLoption>
			<div class="#params.orgFieldID#_orgOptionItem"><input type='radio' name='#arguments.fieldName#' id='#arguments.fieldName#_all' class="customRadioBtn" value='#allOrgsOptionValue#'<cfif arguments.value eq allOrgsOptionValue> checked="checked"</cfif>>&nbsp;<label for='#arguments.fieldName#_all'>#params.allOptionLabel#</label></div>
		</cfif>
		<cfif ArrayLen(orgData)>
			<cfloop from="1" to="#ArrayLen(orgData)#" index="itm">
				<div class="#params.orgFieldID#_orgOptionItem"><input type='radio' name='#arguments.fieldName#' id='#arguments.fieldName#_#itm#' class="customRadioBtn" value='#orgData[itm].uniqueID#'<cfif orgData[itm].uniqueID EQ arguments.value> checked="checked"</cfif>>&nbsp;<label for='#arguments.fieldName#_#itm#'>#orgData[itm].name#</label></div>
			</cfloop>
		</cfif>
	</div>
	</cfoutput>
</cffunction>


<cfscript>
	private struct function setParamDefaults(required string fieldName, required struct parameters)
	{
		var params = arguments.parameters;
		
		if ( NOT StructKeyExists(params,"orgFieldID") OR len(trim(params.orgFieldID)) EQ 0 )
			params.orgFieldID = trim(ReplaceNoCase(arguments.fieldName,'fic_',''));
		else
			params.orgFieldID = trim(params.orgFieldID);
	
		if ( NOT StructKeyExists(params,"catFieldID") )
			params.catFieldID = "";
		else
			params.catFieldID = trim(params.catFieldID);
	
		if( StructKeyExists(params, "useOnlyAciveOrgs") AND (params.useOnlyAciveOrgs EQ "1") )
			params.useOnlyAciveOrgs = true;
		else
			params.useOnlyAciveOrgs = false;
	
		if( StructKeyExists(params, "useALLoption") AND (params.useALLoption EQ "1") )
			params.useALLoption = true;
		else
			params.useALLoption = false;
	
		if( NOT StructKeyExists(params, "allOptionLabel") )
			params.allOptionLabel = ""; // Default is blank since the App should use a value from the Config: All Organizations
		else
			params.allOptionLabel = trim(params.allOptionLabel);
	
		if ( NOT StructKeyExists(params,"defaultOptionType") )
			params.defaultOptionType = "useconfig"; // 'none', 'all', 'record' or 'useconfig'
	
		if( NOT StructKeyExists(params, "defaultOptionValue") )
			params.defaultOptionValue = "";
	
		// Allow the Config value to be overriden via the Field Props (for now!)
		if( NOT StructKeyExists(params, "optionSortField") OR len(trim(params.optionSortField)) EQ 0 OR params.optionSortField EQ "useconfig" ) {
			// Orgs Sort Field from the Confing
			params.optionSortField = application.ptCalendar.getOrgsDisplaySortField();
		} // else 'name' or 'ordinal'
		params.optionSortField = trim(params.optionSortField);
	
		if( NOT StructKeyExists(params, "renderField") )
			params.renderField = "yes";
		
		return params;
	}
	
	private any function getValidationJS(required string formName, required string fieldName, required boolean isRequired)
	{
		if (arguments.isRequired)
			return 'hasValue(document.#arguments.formName#.#arguments.fieldName#, "RADIO")';
		return "";
	}

	private boolean function isMultiline()
	{
		return true;
	}

	private void function renderLabelWrapper(required string label, boolean isRequired=0)
	{
		if (structKeyExists(arguments.parameters, "renderField") && !arguments.parameters.renderField)
			return;
		super.renderLabelWrapper(argumentCollection=arguments);
	}


	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery");
	}
	public string function loadResourceDependencies()
	{
		application.ADF.scripts.loadJQuery();
	}
</cfscript>
</cfcomponent>