<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Calendar directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2010-2016.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->
<!---
/* *************************************************************** */
Author:
	PaperThin Inc.
	M. Carroll
Name:
	calendar_date_time_builder_render.cfm
Summary:
	Custom field to build the Date/Time records.
	This field generates a collection of Date and Times for the field.
Requirements:
	This field type requires a custom hidden field in the custom element with it whose HTML id is configured to be 'calEventID'
ADF App:
	PT Calendar
Version:
	4.0
History:
	2010-09-15 - MFC - Created
	2011-06-15 - GAC - Modified - Added arguments.fieldName to functions and ids to allow field to isolated from other fields on the form
								- Changed the date-time-builder-block id to a class since it may be rendered on a form multiple times
								- Updated the Validation msg
	2011-06-15 - GAC - Moved inside of the ptCalendar app for customization
	2013-04-16 - GAC - Updated to fix stability issues when adding/editing dates
	2015-06-04 - DRM - Converted to CFC for CommonSpot 10.0
	2016-02-25 - DRM - Resource detection support
--->
<cfcomponent extends="ADF.extensions.customfields.adf-form-field-renderer-base" output="no">

<cffunction name="renderControl" access="public" returnType="void">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfargument name="isRequired" type="boolean" required="yes">

	<cfscript>
		var params = setParamDefaults(arguments.fieldName, arguments.parameters);
		var dtbService = "dateTimeBuilderService";
		var dtbController = "dateTimeBuilderController";
		var dtbForm = "dateTimeBuilderForms";
		var useDebugOutput = false;
		// Set defaults for the label and description
		var includeLabel = true;
		var includeDescription = false;

		// Get the DateTime element Name
		var dtDataElementName = application.ptCalendar.getEventDateTimeCEName();
		// Get the DateTime formid
		var dtDataFormID = application.ptCalendar.getEventDateTimeFormID();

		// Check the brokenRecurrence status of this DateTime Record
		var brokenRecurrence = false;
		// Set the newDefaultPickerDate to be prepared if nothing is passed in
		var newDefaultPickerDate = "";

		var dateTimeArray = ArrayNew(1);
		var itm  = 0;

		// Set the the Ajax Loader Image
		var ajaxIMG = '<img width="16" height="16" src="/ADF/apps/pt_calendar/images/ajax-loader-arrows.gif"/>';

		if ( len(trim(arguments.value)) ) {
			dateTimeArray = application.ptCalendar.dateTimeBuilderDAO.getDateTimeData(uuid=arguments.value);
			for (itm=1; itm LTE ArrayLen(dateTimeArray); itm=itm+1 ) {
				if ( StructKeyExists(dateTimeArray[itm],"values") AND StructKeyExists(dateTimeArray[itm].values,"dtHashID") AND len(trim(dateTimeArray[itm].values.dtHashID)) ) {
					brokenRecurrence = true;
					break;
				}
			}
		}
		else {
			// Pass new date URL variable through to the Calendar Picker
			if ( StructKeyExists(request.params,"newSelectedDate") AND IsDate(request.params.newSelectedDate) )
				newDefaultPickerDate = request.params.newSelectedDate;
		}
	</cfscript>

	<cfoutput>
	<!--- Include the app CSS --->
	<link rel="stylesheet" type="text/css" href="/ADF/apps/pt_calendar/style/calendar-datetime-builder.css">

	<style>
		a.addLink_#arguments.fieldName# {
			float:right;
			font-size: 10pt;
		}
		##form_#arguments.fieldName# .loading {
			font-size: 12px;
		}
		##brokenRecurrenceText_#arguments.fieldName#{
			font-size: 11px;
			padding-bottom: 6px;
		}
	</style>

	<script>
		#renderValidationFunction(arguments.fieldName, params)#

		jQuery(function(){

			/****************************/
			/*   DOC READY Functions    */
			/****************************/

			// Get any Date/Times that have been configured
			reloadDateTimes_#arguments.fieldName#(0,1);

			<!--- // If this event is a broked recurrence then Hide the Recurrence Properties FIELD table ROW --->
			<cfif brokenRecurrence AND len(trim(params.recurrFieldID))>
				jQuery("###params.recurrFieldID#").parents("tr:first").hide();
			</cfif>

			// addDateTime without action page
			jQuery("##addDateTimeLink_#arguments.fieldName#").click(function() {
				addDataTime_#arguments.fieldName#();
			});

		});

		/****************************/
		/*      Ajax Functions      */
		/****************************/

		// Function to render the links for the record
		function reloadDateTimes_#arguments.fieldName#(reloadWait,doElementDataSync) {
			reloadWait = reloadWait !== undefined ? reloadWait : 1000;
			doElementDataSync = doElementDataSync !== undefined ? doElementDataSync : true;
			// init the current vals variable
			var currVals = "";
			var buttonText = '#params.btnText#';

			if ( doElementDataSync ) {
				syncFieldValue_#arguments.fieldName#();
			}

			// Display the loading Message
			jQuery("##form_#arguments.fieldName#").html('<div class="loading">#ajaxIMG# Building Dates and Times...</div>');

			// Reload the schedule records
			setTimeout( function() {

				// get the current vals	(again to make sure we have update data)
				currVals = getCurrentFieldData_#arguments.fieldName#();
				getDateTimesHTML_#arguments.fieldName#(currVals,buttonText);

			}, reloadWait );
		}
		// Function to render the schedule records
		function getDateTimesHTML_#arguments.fieldName#(itemIDlist,btnText) {
			itemIDlist = itemIDlist !== undefined ? itemIDlist : "";
			btnText = btnText !== undefined ? btnText : "Add New Item";

			// load the html to render the selected items base on a list of items
			jQuery.get( "#application.ADF.ajaxProxy#",
			{
				bean: "#dtbController#"
				,method: 'renderDateTimeHTML'
				,uuidlist: itemIDlist
				,buttonText: '#params.btnText#'
			},
			function(msg){
				// Render the Selections Display
				renderSelectionsDisplayHTML(msg);
			});
		}
		// Use this function to keep event field value and recurrence element values in sync
		function syncFieldValue_#arguments.fieldName#(){
			// Get the parentID from the uniqueID field from the FORM
			var parentID = getParentIDFieldData_#arguments.fieldName#();
			// get the current vals
								//alert(parentID + '@customfields/date_time_builder/calendar_date_time_builder_render.cfc:204'); // TODO: kill this
			jQuery.get("#application.ADF.ajaxProxy#",
				{
					bean: "#dtbService#"
					,method: 'buildDateTimeIDListByParentID'
					,parentID: parentID
				},
				function(data) {
					// Setthe values of the arguments.fieldName field
					setCurrentFieldData_#arguments.fieldName#(data);
				}
			);
		}

		/****************************/
		/*    Utility Functions     */
		/****************************/

		// Function to RETURN the current value that is stored in CFT's hidden field
		function getCurrentFieldData_#arguments.fieldName#() {
			var retVal = jQuery("input[name=#arguments.fieldName#]").val();

			<cfif useDebugOutput>
			console.log("getCurrentFieldData:");
			console.log("retVal: " + retVal);
			</cfif>
			return retVal;
		}
		// Function to RETURN the current value that is stored in CFT's hidden field
		function getParentIDFieldData_#arguments.fieldName#() {
			var retVal = jQuery("##calEventID").val();

			<cfif useDebugOutput>
			console.log("getParentIDFieldData:");
			console.log("retVal: " + retVal);
			</cfif>
			return retVal;
		}
		// Function to SET the current value that is stored in CFT's hidden field
		function setCurrentFieldData_#arguments.fieldName#(fieldData) {
			jQuery("input[name=#arguments.fieldName#]").val(fieldData);

			<cfif useDebugOutput>
			console.log("setCurrentFieldData:");
			console.log("fieldData: " + fieldData);
			</cfif>
		}
		// Function to RENDER the current selection list UI display
		function renderSelectionsDisplayHTML(htmlData) {
			jQuery("##form_#arguments.fieldName#").html(htmlData);

			<cfif useDebugOutput>
			console.log("renderSelectionsDisplayHTML:");
			console.log("htmlData: " + htmlData);
			</cfif>

			// Load the click handlers for the datetime edit/delete links
			loadActionButtons_#arguments.fieldName#();

			// Resize Lightbox window
			if ( typeof lbResizeWindow == 'function' )
				lbResizeWindow();
			else if ( typeof ResizeWindow == 'function' )
				ResizeWindow();
		}
		// Function to load Events with edit and delete links
		function loadActionButtons_#arguments.fieldName#() {
			jQuery("a.date-time-builder-edit").click(function() {
		    	var currUUID = jQuery(this).attr("id");
		    	editDateTime_#arguments.fieldName#(currUUID);
		    });

		    jQuery("a.date-time-builder-remove").click(function() {
		    	var currUUID = jQuery(this).attr("id");
		    	removeDateTime_#arguments.fieldName#(currUUID);
		    });

		    // Hover states on the static widgets
			jQuery("div.date-time-builder-block div.ui-button").hover(
				function() {
					jQuery(this).css("cursor", "hand");
					jQuery(this).addClass("ui-state-hover");
				},
				function() {
					jQuery(this).css("cursor", "pointer");
					jQuery(this).removeClass('ui-state-hover');
				}
			);
		}
		// Serialize the selections
		function serialize_#arguments.fieldName#() {
			// load current values into the form field
			jQuery("input[name=#arguments.fieldName#]").val(jQuery('##form_#arguments.fieldName#').sortable( 'toArray' ));
		}

		/****************************/
		/*    CallBack Functions    */
		/****************************/

		// Callback function for the add/edit links
		function addEdit_cbFunct_#arguments.fieldName#(inArgsArray) {
			var newUUID = inArgsArray[0];
			var eventID = inArgsArray[1];
			var action = inArgsArray[2];

			// Get the current values from the arguments.fieldName field
			var currVals = getCurrentFieldData_#arguments.fieldName#();

			// Update the arguments.fieldName field with the new UUID
			jQuery.get( "#application.ADF.ajaxProxy#", {
				bean: "#dtbService#",
				method: 'listManagement',
				currList: currVals,
				currItem: newUUID,
				actionType: action
			},
			function(data){

				// Get the values of the arguments.fieldName field
				setCurrentFieldData_#arguments.fieldName#(data);

				// Reload the schedule records
				reloadDateTimes_#arguments.fieldName#(2000);

			});
		}
		// Callback function for the remove links
		function remove_cbFunct_#arguments.fieldName#(cbValues){
			// Close the current LB layer for the delete form
			closeLB();
			// Set the list management action
			var action = 'remove';
			// Set the RemoveID value from the passed in cbIDlist
			var removeID = "";

			if ( cbValues.hasOwnProperty("cbIDlist") )
				removeID = cbValues.cbIDlist;

			// Get the current values from the arguments.fieldName field
			var currVals = getCurrentFieldData_#arguments.fieldName#();

			// Update the field and then re-render the display
			jQuery.get( "#application.ADF.ajaxProxy#", {
				bean: "#dtbService#",
				method: 'listManagement',
				currList: currVals,
				currItem: removeID,
				actionType: action
			},
			function(data){
				// Set the value back into the save field
				setCurrentFieldData_#arguments.fieldName#(data);
				// Reload the render dateTime blocks
				reloadDateTimes_#arguments.fieldName#();
			});
		}

		/****************************/
		/*    UI Button Functions   */
		/****************************/

		// Function to open form to create new dateTime entries
		function addDataTime_#arguments.fieldName#(){
			// Get the parentID from the uniqueID field from the FORM
			var parentID = getParentIDFieldData_#arguments.fieldName#();
			<!--- // If a new default date picker date is passed in add that to the URL parameters --->
			<cfif len(trim(newDefaultPickerDate))>
			openLB("#application.ADF.lightboxProxy#?bean=#dtbForm#&method=renderDateTimeForm&dataPageID=0&eventid=" + parentID + "&callback=addEdit_cbFunct_#arguments.fieldName#&title=Add Date/Time&newSelectedDate=#newDefaultPickerDate#");
			<cfelse>
			openLB("#application.ADF.lightboxProxy#?bean=#dtbForm#&method=renderDateTimeForm&dataPageID=0&eventid=" + parentID + "&callback=addEdit_cbFunct_#arguments.fieldName#&title=Add Date/Time");
			</cfif>
		}

		// Function to open form to edit dateTime entries
		function editDateTime_#arguments.fieldName#(datetimeid) {
			// Get the parentID from the uniqueID field from the FORM
			var parentID = getParentIDFieldData_#arguments.fieldName#();
			openLB("#application.ADF.lightboxProxy#?bean=#dtbForm#&method=renderDateTimeForm&dateTimeID=" + datetimeid + "&eventid=" + parentID + "&callback=addEdit_cbFunct_#arguments.fieldName#&title=Edit Date/Time");
		}

		function removeDateTime_#arguments.fieldName#(datetimeid) {
			openLB("#application.ADF.lightboxProxy#?bean=#dtbForm#&method=renderDateTimeDeleteForm&dateTimeID=" + datetimeid + "&callback=remove_cbFunct_#arguments.fieldName#&cbIDlist=" + datetimeid + "&title=Delete Date/Time");
		}
	</script>

	<!--- // Build the field inner HTML --->
	<div class="date-time-builder-block">
		<!--- // Do NOT display ADD button if this is a Broken Recurrence DateTime --->
		<!--- // - So ONLY Display Button if this is a static dateTime or part of a Parent Recurrence event  --->
		<cfif !brokenRecurrence>
			<div id="addDateTimeLink_#arguments.fieldName#" class="ui-button ui-state-default ui-corner-all">#params.btnText#</div>
		<cfelse>
			<div id="brokenRecurrenceText_#arguments.fieldName#">
				This event was part of a 'Recurrence Series' but has been modified from the original.
			</div>
		</cfif>
		<div style="clear: both;"></div>
		<!--- // DIV where DateTime blocks are loaded --->
		<div id="form_#arguments.fieldName#"></div>
		<!--- hidden field to store the value --->
		<input type="hidden" name="#arguments.fieldName#" value="#arguments.value#" id="#params.fieldID#" class="#params.fieldClass#" size="40">
	</div>
	</cfoutput>
</cffunction>


<cffunction name="renderValidationFunction" returntype="void">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="parameters" type="struct" required="yes">
	<cfoutput>
		function validate_#arguments.fieldName#(useBind, isRequired)
		{
			var dtValue = jQuery("input[name=#arguments.fieldName#]").val().trim();
			//console.log(useBind, isRequired, dtValue);
			
			if (useBind)
			{
				var recurValue = jQuery("###arguments.parameters.recurrFieldID#").val().trim();
				return (dtValue.length || recurValue.length)
			}
			else if (isRequired)
				return (dtValue !== '');
				
			return true;
		}
	</cfoutput>
</cffunction>


<cfscript>
	private any function getValidationJS(required string formName, required string fieldName, required boolean isRequired)
	{
		var useBind = (arguments.parameters.bindRequired EQ 'one' AND len(arguments.parameters.recurrFieldID)) ? "true" : "false";
		var isRequiredStr = arguments.isRequired ? "true" : "false";
		return 'validate_#arguments.fieldName#(#useBind#, #isRequiredStr#)';
	}
	private string function getValidationMsg()
	{
		if (arguments.parameters.bindRequired EQ 'one' AND len(arguments.parameters.recurrFieldID))
			return "Please add a Date/Time entry or set-up Recurrence Properties.";
		return "Please add a Date/Time entry.";
	}

	private struct function setParamDefaults(required string fieldName, required struct parameters)
	{
		var params = arguments.parameters;

		if ( NOT StructKeyExists(params, "fieldID") )
			params.fieldID = arguments.fieldName;
		else
			params.fieldID = trim(params.fieldID);

		if ( (NOT StructKeyExists(params, "fieldClass")) OR ( len(trim(params.fieldClass)) LTE 0) )
			params.fieldClass = "";
		if ( (NOT StructKeyExists(params, "btnText")) OR ( len(trim(params.btnText)) LTE 0) )
			params.btnText = "Add New Date/Time";

		if ( (NOT StructKeyExists(params, "recurrFieldID")) OR ( len(trim(params.recurrFieldID)) LTE 0) )
			params.recurrFieldID = "";
		else
			params.recurrFieldID = trim(params.recurrFieldID);

		// If bound to a Recurrence Build field set the required field properties
		if ( (NOT StructKeyExists(params, "bindRequired")) OR ( len(trim(params.bindRequired)) LTE 0) )
			params.bindRequired = "none"; // none = standard field required behavior | one = one of the bound fields must have a value

		return params;
	}

	private boolean function isMultiline()
	{
		return true;
	}

	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery,jQueryUI,ADFLightbox");
	}
	public string function loadResourceDependencies()
	{
		application.ptCalendar.scripts.loadJQuery();
		application.ptCalendar.scripts.loadJQueryUI(themeName=application.ptCalendar.getUItheme());
		application.ptCalendar.scripts.loadADFLightbox();
	}
</cfscript>

</cfcomponent>