<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Calendar directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2010-2016.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	G. Cronkright 
Custom Field Type:
	Event Category Checkbox Field
Name:
	event_category_checkboxes_props.cfm
Summary:
	Custom Field to select event categories from a list of checkboxes. 
	These categories can be bound to the Calendar Organizations radio button
	field. When a different organization is selected that organizations 
	associated category checkboxes are rendered.
History:
	2011-08-18 - GAC - Created
	2014-09-25 - GAC - Removed deprecated doLabel and jsLabelUpdater js calls
					 	  - Added the fieldVersion variable
	2015-06-04 - DRM - Bumped field version
	2016-02-25 - DRM - Remove force scripts UI
						  - Bump field version
--->
<cfscript>
	// Variable for the version of the field - Display in Props UI.
	fieldVersion = "2.0.1";
	
	// initialize some of the attributes variables
	typeid = attributes.typeid;
	prefix = attributes.prefix;
	formname = attributes.formname;
	currentValues = attributes.currentValues;

	if ( NOT StructKeyExists(currentValues, "catFieldID") )
		currentValues.catFieldID = "";
	if ( NOT StructKeyExists(currentValues, "catFieldNoneMsg") )
		currentValues.catFieldNoneMsg = "";	
	if ( NOT StructKeyExists(currentValues, "orgFieldID") )
		currentValues.orgFieldID = "";
	if ( NOT StructKeyExists(currentValues, "orgFieldNoneMsg") )
		currentValues.orgFieldNoneMsg = "";
	if ( NOT structKeyExists(currentValues, "useOnlyAciveCats") )
		currentValues.useOnlyAciveCats = "0";
	
	// Allow the Config value to be overriden via the Field Props (for now!)
	if ( NOT structKeyExists(currentValues, "optionSortField") ) 
		currentValues.optionSortField = "useconfig";  // name or Ordinal
</cfscript>

<cfoutput>
	<script language="JavaScript" type="text/javascript">
		// register the fields with global props object
		fieldProperties['#typeid#'].paramFields = '#prefix#catFieldID,#prefix#orgFieldID,#prefix#catFieldNoneMsg,#prefix#orgFieldNoneMsg,#prefix#useOnlyAciveCats,#prefix#optionSortField';
	</script>

	<table>
		<tr>
			<td colspan="2" class="cs_dlgLabelSmall"><strong>Category and Organization Field Bindings:</strong></td>
		</tr>	
		<tr>
			<td class="cs_dlgLabelSmall">Category Field ID:</td>
			<td class="cs_dlgLabelSmall">
				<input type="text" name="#prefix#catFieldID" id="#prefix#catFieldID" value="#currentValues.catFieldID#" />
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Organization Field ID:</td>
			<td class="cs_dlgLabelSmall">
				<input type="text" name="#prefix#orgFieldID" id="#prefix#orgFieldID" value="#currentValues.orgFieldID#" />
				<br/>Used to bind this category checkbox field to an organization radio button field.
			</td>
		</tr>
		<tr>
			<td colspan="2" class="cs_dlgLabelSmall"><hr></td>
		</tr>
		<tr>
			<td colspan="2" class="cs_dlgLabelSmall"><strong>Category and Organization 'No Results' Messages:</strong></td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Category Message:</td>
			<td class="cs_dlgLabelSmall">
				<input type="text" name="#prefix#catFieldNoneMsg" id="#prefix#catFieldNoneMsg" value="#currentValues.catFieldNoneMsg#" size="50" />
				<br/>Text to display if no categories are returned. 
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Organization Message:</td>
			<td class="cs_dlgLabelSmall">
				<input type="text" name="#prefix#orgFieldNoneMsg" id="#prefix#orgFieldNoneMsg" value="#currentValues.orgFieldNoneMsg#" size="50" />
				<br/>Text to display if an organization has not been selected. 
				<br/>(Only used if an Organization Field ID has been entered.)
			</td>
		</tr>
		<tr>
			<td colspan="2" class="cs_dlgLabelSmall"><hr></td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Only Display Active Categories:</td>
			<td class="cs_dlgLabelSmall">
				Yes <input type="radio" id="#prefix#useOnlyAciveCats" name="#prefix#useOnlyAciveCats" value="1"<cfif currentValues.useOnlyAciveCats EQ "1"> checked="checked"</cfif>>&nbsp;&nbsp;&nbsp;
				No <input type="radio" id="#prefix#useOnlyAciveCats" name="#prefix#useOnlyAciveCats" value="0"<cfif currentValues.useOnlyAciveCats EQ "0"> checked="checked"</cfif>><br />
			</td>
		</tr>
		<tr>
			<td colspan="2" class="cs_dlgLabelSmall"><hr></td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall">Sort Field:</td>
			<td class="cs_dlgLabelSmall">
				Name (A-Z) <input type="radio" id="#prefix#optionSortFieldName" name="#prefix#optionSortField" value="name"<cfif currentValues.optionSortField EQ "name"> checked="checked"</cfif>>&nbsp;&nbsp;&nbsp;
				Ordinal (0-9) <input type="radio" id="#prefix#optionSortFieldOrdinal" name="#prefix#optionSortField" value="ordinal"<cfif currentValues.optionSortField EQ "ordinal"> checked="checked"</cfif>>&nbsp;&nbsp;&nbsp;
				Use App Config <input type="radio" id="#prefix#optionSortFieldConfig" name="#prefix#optionSortField" value="useconfig"<cfif currentValues.optionSortField EQ "useconfig"> checked="checked"</cfif>><br />
			</td>
		</tr>
		<tr>
			<td class="cs_dlgLabelSmall" colspan="2" style="font-size:7pt;">
				<hr />
				ADF Custom Field v#fieldVersion#
			</td>
		</tr>
	</table>
</cfoutput>