<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Calendar directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2010-2016.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->
<!---
/* *************************************************************** */
Author:
	PaperThin, Inc.
	G. Cronkright
Custom Field Type:
	Event Category Checkbox Field
Name:
	event_category_checkboxes_render.cfm
Summary:
	Custom Field to select event categories from a list of checkboxes.
	These categories can be bound to the Calendar Organizations radio button
	field. When a different organization is selected that organizations
	associated category checkboxes are rendered.
History:
	2011-08-18 - GAC - Created
	2015-06-04 - DRM - Converted to cfc for ADF 2.0/CommonSpot 10
						  - Much cruft and confusion removal
						  - One notable change is that it always gets the value of the All Organizations radio from the app
	2016-02-25 - DRM - Resource detection support
						  - Remove force scripts support
  --->
<cfcomponent extends="ADF.extensions.customfields.adf-form-field-renderer-base" output="no">

<cffunction name="renderControl" access="public" returnType="void">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfargument name="isRequired" type="boolean" required="yes">

	<cfscript>
		var params = setParamDefaults(arguments.fieldName, arguments.parameters);
		var allOrgsOptionValue =  application.ptCalendar.getAllOrganizationsValue();
		var ajaxLoadingHTML = 'Loading Categories...<img src="/ADF/lib/ajax/images/ajax-loader-arrows.gif">';
	</cfscript>

	<cfoutput>
		<style type="text/css">
		###arguments.fieldName#_label {position: relative; top: 5px;}
		##msg_#params.catFieldID# {padding-top: 3px;}
		###arguments.fieldName#_checkboxTable td {padding: 0;}
		###arguments.fieldName#_checkboxTable td > label {font-weight: normal;}
		</style>
		<script>
			jQuery(function(){
				jQuery("###arguments.fieldName#_LoadingStatus").hide();
				
				<cfif LEN(params.catFieldID) AND LEN(params.orgFieldID) EQ 0>
				// Load the Cats here... if the ORG field is not Bound via the PROPS
				loadCategories_#params.catFieldID#();
				</cfif>
			});

			function showMsg_#params.catFieldID#(msg)
			{
				var htmlString = '<tr><td id="msg_#params.catFieldID#">' + msg + '</td></tr>';
				jQuery("table###arguments.fieldName#_cbTable").html(htmlString);
			}
			
			<cfif LEN(params.orgFieldID)>
			// Set up what to display if no value is passed from the orgFileID
			function loadCategoriesNoneSelectedMsg_#params.catFieldID#(){
				showMsg_#params.catFieldID#('#params.orgFieldNoneMsg#');
			}
			</cfif>
			
			function clearCheckedCategories_#params.catFieldID#() {
				// Clear all the checkboxes
				jQuery("table###arguments.fieldName#_cbTable").empty();
				// jQuery("input[name='#arguments.fieldName#_checkbox']:checkbox").unCheckCheckboxes();
				jQuery("input[name='#arguments.fieldName#']").val(''); 	
			}
			
			<!--- // We need to use the params.catFieldID because this function may be triggered by the Organizations CFT --->
			function loadCategories_#params.catFieldID#(selectedOrgValue,loadCatSelections) {
				// if no selectedOrgValue is passed in then set it to an empty string
				selectedOrgValue = selectedOrgValue !== undefined ? selectedOrgValue : "";
				// if the selectedOrgValue that is passed in matches the allOrgsOptionValue
				// then reset the selectedOrgValue to an empty string to return all categories
				if ( selectedOrgValue == '#allOrgsOptionValue#' ) {
					selectedOrgValue = '';
				}
				
				// if loadCatSelections is not passed in then set it to 'true'
				loadCatSelections = loadCatSelections !== undefined ? loadCatSelections : "true";

				// Show Loading after process has run
				jQuery("###arguments.fieldName#_LoadingStatus").show();
				//jQuery("table###params.catFieldID#_catOptionsBox").slideUp(3000);
				
				// Remove all of the current checkbox input fields
				jQuery("table###arguments.fieldName#_cbTable").empty();
				// Clear all the checkboxes
				// jQuery("input[name='#arguments.fieldName#_checkbox']:checkbox").unCheckCheckboxes();
				// Remove the current values
				jQuery("input[name='#arguments.fieldName#']").val('');
	
				// Set the key value pairs to pass the the Ajax function
				var ajaxPostVars = { 
										appName: "ptCalendar",
										bean: "calEventCategoriesDAO",
										method: "getFilteredCategoriesByOrgID",
										orgID: selectedOrgValue,
										<cfif params.useOnlyAciveCats>
										filterField: "active",
										filterValue: 1,
										</cfif>
										<cfif LEN(params.optionSortField)>
										sortField: '#params.optionSortField#',
										</cfif>
										returnformat: "json"
									}; 
									
				// Get the selected Categories
				jQuery.post("#application.ADF.ajaxProxy#",
					ajaxPostVars,
					function(results) {
						var htmlString = '';
						if ( results.length >=1 ) {
							for ( var i=0; i < results.length; i++ ) {
								htmlString = htmlString + addCSCheckbox_#arguments.fieldName#(results[i].VALUES.catID,results[i].VALUES.name,0,i,results.length);
							}
							jQuery("table###arguments.fieldName#_cbTable").append(htmlString);
						}
						else {
							showMsg_#params.catFieldID#('#params.catFieldNoneMsg#');
						}
						
						
						if ( loadCatSelections ) {
							// add the checks to the selected checkboxs 
							loadCurrentSelectedValues_#arguments.fieldName#();
						}
						
						// Load Click event for Dynamic Checkboxes
						loadCheckBoxActions_#arguments.fieldName#();
						
						// Hide Loading after process has run
						jQuery("###arguments.fieldName#_LoadingStatus").hide();
						//jQuery("table###params.catFieldID#_catOptionsBox").slideDown(3000);	
						
						// Resize Lightbox window
						if ( typeof lbResizeWindow == 'function' )
							lbResizeWindow();
						else if ( typeof ResizeWindow == 'function' )
							ResizeWindow();		
					},
					"json"
				);
				
				// Hide Loading after process has run
				//jQuery("###arguments.fieldName#_LoadingStatus").hide();	
			}
			
			function loadCurrentSelectedValues_#arguments.fieldName#(){		
				var selectedCats = '#arguments.value#';
				for (i=1; i <= jQuery.ListLen(selectedCats); i++) {
					currentVal = "input[value="+jQuery.ListGetAt(selectedCats,i)+"]";
					//console.dir(jQuery(currentVal));
					jQuery(currentVal).attr('checked', true);
				}
				// Make sure the hidden field has the correct values 
				jQuery("input[name='#arguments.fieldName#']").val(selectedCats);
			}
	
			function addCSCheckbox_#arguments.fieldName#(uuid,name,rowbreak,currentRow,totalRows) {
				var html = '';
				var rowBreak = 2;
				var renderRowStart = false;
				var renderRowEnd = false;
	
				if (currentRow % rowBreak == 0)
					renderRowStart = true;
				else 
					renderRowEnd = true;
	
				if (currentRow == totalRows)
					renderRowEnd = true;
	
				if (renderRowStart)
					html = '<tr>';
	
				html = html + '<td>';
				html = html + '<table id="#arguments.fieldName#_checkboxTable" cellpadding="0" cellspacing="0" border="0" summary=""><tr>';
				
				html = html + '<td><input type="checkbox" name="#arguments.fieldName#_checkbox" value="'+uuid+'" id="#arguments.fieldName#_checkbox_'+uuid+'"></td>';
				html = html + '<td><label for="#arguments.fieldName#_checkbox_'+uuid+'">&nbsp;'+name+'</label></td>';
				html = html + '<td>&nbsp;&nbsp;&nbsp;</td>';
	
				html = html + '</tr></table>';
				html = html + '</td>';
				
				if (renderRowEnd)
					html = html + '</tr>';
				
				return html;
			}
			
			// Function to load Events with edit and delete links 
			function loadCheckBoxActions_#arguments.fieldName#() {
				
				jQuery("input[name='#arguments.fieldName#_checkbox']").click(function(){
					var clickedVal = jQuery(this).val();
					var currentFieldVal = jQuery("input[name='#arguments.fieldName#']").val();
					var clickedIDpos = jQuery.ListFindNoCase(currentFieldVal,clickedVal);
					//console.log('Checked ID:' + checkedVal);
				
					// When it was clicked was the checkbox checked or unchecked 
					if ( jQuery(this).is(':checked') ) {
						// Add the checked CatID to value list in the CFT hidden field to store the checked options
						if ( !clickedIDpos ) {
							currentFieldVal = jQuery.ListAppend(currentFieldVal,clickedVal);
							jQuery("input[name='#arguments.fieldName#']").val(currentFieldVal);
						}
									
					}	
					else {
						// Remove the checked CatID from the value list in CFT hidden field to store the checked options
						if ( clickedIDpos ) {
							currentFieldVal = jQuery.ListDeleteAt(currentFieldVal,clickedIDpos);
							jQuery("input[name='#arguments.fieldName#']").val(currentFieldVal);
						}			
					}
				 });
				 
			}
		</script>
		
		<style>
			###arguments.fieldName#_LoadingStatus {
				font-size: 11px;
				display: none;
			}
		</style>
		
		<div id="#arguments.fieldName#_LoadingStatus">
			<span>#ajaxLoadingHTML#</span>
		</div>
		<div id="#arguments.fieldName#_catOptionsBox">
			<table id="#arguments.fieldName#_cbTable"><tr><td>#ajaxLoadingHTML#</td></tr></table>
		</div>
		<!--- // hidden field to store the values --->
		<input type="hidden" name="#arguments.fieldName#" id="#params.catFieldID#" value="#arguments.value#">
	</cfoutput>
</cffunction>
	
	
<cfscript>
	private struct function setParamDefaults(required string fieldName, required struct parameters)
	{
		var params = arguments.parameters;

		if (NOT StructKeyExists(params, "catFieldID") OR LEN(trim(params.catFieldID)) EQ 0)
			params.catFieldID = trim(ReplaceNoCase(arguments.fieldName, 'fic_', ''));
		else
			params.catFieldID = trim(params.catFieldID);

		if (NOT StructKeyExists(params, "orgFieldID"))
			params.orgFieldID = "";
		else
			params.orgFieldID = trim(params.orgFieldID);

		if (NOT StructKeyExists(params, "catFieldNoneMsg") OR LEN(trim(params.catFieldNoneMsg)) EQ 0)
			params.catFieldNoneMsg = "No Categories were found";
		else
			params.catFieldNoneMsg = trim(params.catFieldNoneMsg);

		if (NOT StructKeyExists(params, "orgFieldNoneMsg") OR LEN(trim(params.orgFieldNoneMsg)) EQ 0)
			params.orgFieldNoneMsg = "Please select an Organization";
		else
			params.orgFieldNoneMsg = trim(params.orgFieldNoneMsg);

		if (StructKeyExists(params, "useOnlyAciveCats") AND (params.useOnlyAciveCats EQ "1"))
			params.useOnlyAciveCats = true;
		else
			params.useOnlyAciveCats = false;

		// Allow the Config value to be overriden via the Field Props (for now!)
		if (NOT StructKeyExists(params, "optionSortField") OR LEN(trim(params.optionSortField)) EQ 0 OR params.optionSortField EQ "useconfig")
		{
			// Orgs Sort Field from the Confing
			params.optionSortField = application.ptCalendar.getCatsDisplaySortField();
		} // else 'name' or 'ordinal'
		params.optionSortField = trim(params.optionSortField);

		return params;
	}

	private any function getValidationJS(required string formName, required string fieldName)
	{
		if (arguments.isRequired)
			return "hasValue(document.getElementById('#arguments.parameters.catFieldID#'), 'TEXT')";
		return "";
	}

	private boolean function isMultiline()
	{
		return true; // not sure really, depends on how many checkboxes there are
	}

	private boolean function useLabelFor()
	{
		return false; // multiple checkboxes, none w that id
	}

	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery,CFJS,JQueryCheckboxes");
	}
	public string function loadResourceDependencies()
	{
		application.ptCalendar.scripts.loadjQuery();
		application.ptCalendar.scripts.loadCFJS();
		application.ptCalendar.scripts.loadJQueryCheckboxes();
	}
</cfscript>


</cfcomponent>