<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Calendar directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2010-2016.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->
<!---
/* *************************************************************** */
Author:
	PaperThin Inc.
	G. Cronkright
Name:
	calendar_recurrence_builder_render.cfm
Summary:
	Custom field to build the Event recurrence records for the Calendar App.
ADF App:
	PT Calendar
Version:
	4.0
History:
	2011-06-23 - GAC - Created
	2015-06-05 - DRM - Converted to CFC for cs 10.0
	2016-02-25 - DRM - Resource detection support
--->
<cfcomponent extends="ADF.extensions.customfields.adf-form-field-renderer-base" output="no">

<cffunction name="renderControl" access="public" returnType="void">
	<cfscript>
		// If the ptCalendar bean name has been defined get the app config
		var appConfig = structKeyExists(application,"ptCalendar") ? application.ptCalendar.getAppConfig() : {};
	
		var rbController = "recurrenceBuilderController";
		var rbService = "recurrenceBuilderService";
		var rbForm = "recurrenceBuilderForms";
	
		// the param structure which will hold all of the fields from the props dialog
		var params = setParamDefaults(arguments.fieldName, arguments.parameters);

		// Set the NO Records Text
		var noRecordsText = "Recurrence has not been setup for this event.<br/>Click '#params.btnAddText#' to select recurrence properties.";

		var ajaxIMG = '<img width="16" height="16" src="/ADF/apps/pt_calendar/images/ajax-loader-arrows.gif"/>';
	
		// Set the newDefaultPickerDate to be prepared if nothing is passed in
		var newDefaultPickerDate = "";
	
		if ( len(trim(arguments.value)) EQ 0 ) {
			// Pass new date URL variable through to the Calendar Picker
			if ( StructKeyExists(request.params,"newSelectedDate") AND IsDate(request.params.newSelectedDate) )
				newDefaultPickerDate = request.params.newSelectedDate;
		}
	</cfscript>
	
	<cfoutput>
		<!--- Include the app CSS --->
		<link rel="stylesheet" type="text/css" href="/ADF/apps/pt_calendar/style/calendar-recurrence-builder.css">
	
		<style>
			a.addLink_#arguments.fieldName# {
				float:right;
				font-size: 10pt;
			}
		</style>
	
		<script>
			// javascript validation to make sure they have text to be converted
			#arguments.fieldName# = {};
			#arguments.fieldName#.id = '#arguments.fieldName#';
			#arguments.fieldName#.tid = '#arguments.renderTabIndex#';
			#arguments.fieldName#.validator = "validate_#arguments.fieldName#()";
			#arguments.fieldName#.msg = "Please set-up Recurrence Properties.";
	
			// Check if the field is required
			if ( '#params.req#' == 'Yes' ) {
				// push on to validation array
				vobjects_#arguments.formName#.push(#arguments.fieldName#);
			}
	
			function validate_#arguments.fieldName#() {
				if (jQuery("input[name=#arguments.fieldName#]").val() != '')
				{
					return true;
				}
				else {
					return false;
				}
			}
		</script>
	
		<script>
			jQuery(function() {
				// Get any Recurrence Properties that have been configured
				renderRecurrence_#arguments.fieldName#();
	
				// add Recurrence without action page
				jQuery("##addRecurrenceLink_#arguments.fieldName#").click(function() {
					addRecurrence_#arguments.fieldName#();
				});
	
				// edit Recurrence without action page
				jQuery("##editRecurrenceLink_#arguments.fieldName#").click(function() {
					editRecurrence_#arguments.fieldName#();
				});
			});
	
			// Function to render the selected recurrence values for this field
			function renderRecurrence_#arguments.fieldName#() {
				// Sync the fieldValue with the element
				syncFieldValue_#arguments.fieldName#();

				var currVals = jQuery("input[name=#arguments.fieldName#]").val();

				if ( jQuery.trim(currVals).length ) {
					// If the field contains UUID values display the loading message
					jQuery("##display_#arguments.fieldName#").html('#ajaxIMG# Loading Recurrence...');
				}

				// load the recurrence data (or the no recurrence message)
				jQuery.get( "#application.ADF.ajaxProxy#",{
					bean: "#rbController#"
					,method: 'renderRecurrenceHTML'
					,uuidlist: currVals
				},
				function(msg) {
					if ( jQuery.trim(msg).length ) {
						// Hide the 'Add Recurrence' button
						//jQuery("##addRecurrenceLink_#arguments.fieldName#").hide();

						// Show/Hide the Add and the Edit buttons
						jQuery("##addRecurrenceLink_#arguments.fieldName#").hide();
						jQuery("##editRecurrenceLink_#arguments.fieldName#").show();

						// Output the recurrence records or the no records message
						jQuery("##display_#arguments.fieldName#").html(msg);
						// Load the click handlers for the recurrence edit/delete links
						loadActionButtons_#arguments.fieldName#();
					}
					else {
						// Show the 'Add Recurrence' button
						//jQuery("##addRecurrenceLink_#arguments.fieldName#").show();

						// Show/Hide the Add and the Edit buttons
						jQuery("##addRecurrenceLink_#arguments.fieldName#").show();
						jQuery("##editRecurrenceLink_#arguments.fieldName#").hide();

						// Display no records message
						msg = "<div class='recurrence-text'>#noRecordsText#</div>";

						// Display the NO RECORDS message
						jQuery("##display_#arguments.fieldName#").html(msg);
					}
					// Resize Lightbox window
					if ( typeof lbResizeWindow == 'function' )
						lbResizeWindow();
					else if ( typeof ResizeWindow == 'function' )
						ResizeWindow();
				});
			}

			// Function to load Events with edit and delete links
			function loadActionButtons_#arguments.fieldName#(){
				 // enable the trash can icon under the recurrence properties
				 jQuery("a.recurrence-builder-remove").click(function() {
					var currUUID = jQuery(this).attr("id");
					removeRecurrenceItem_#arguments.fieldName#(currUUID);
				 });

				 // Hover states on the static widgets
				jQuery("div.recurrence-builder-block div.ui-button").hover(
					function() {
						jQuery(this).css("cursor", "hand");
						jQuery(this).addClass("ui-state-hover");
					},
					function() {
						jQuery(this).css("cursor", "pointer");
						jQuery(this).removeClass('ui-state-hover');
					}
				);
			}

			// Use this function to keep event field value and recurrence element values in sync
			function syncFieldValue_#arguments.fieldName#() {
				var eventID = jQuery("##calEventID").val();
				var currVals = "";
				// get the current vals
				jQuery.get("#application.ADF.ajaxProxy#",{
						bean: "#rbService#"
						,method: 'buildRecurrenceIDListByParentID'
						,parentID: eventID
					},
					function(data) {
						jQuery("input[name=#arguments.fieldName#]").val(data);
					}
				);
			}
	
			/****************************/
			/*    CallBack Functions    */
			/****************************/
	
			// Callback function for the add/edit recurrence link
			function addEditRecurrence_cbFunct_#arguments.fieldName#(inArgsArray){
				var  recurrenceID = inArgsArray[0];
				var eventID = inArgsArray[1];
				var action = inArgsArray[2];
	
				// Update the arguments.fieldName field with the new UUID
				var currFieldVal = jQuery("input[name=#arguments.fieldName#]").val();
	
				// load the initial list items based on the top terms from the chosen facet
				jQuery.get( "#application.ADF.ajaxProxy#", {
					bean: "#rbService#",
					method: 'listManagement',
					currList: currFieldVal,
					currItem: recurrenceID,
					actionType: action
				},
				function(data) {
					// Set the value back into the save field
					jQuery("input[name=#arguments.fieldName#]").val(data);
					// Reload the render links content
					renderRecurrence_#arguments.fieldName#();
				});
			}
			// Callback function for the remove  recurrence link
			function remove_cbFunct_#arguments.fieldName#(cbValues) {
				// Close the current LB layer for the delete form
				closeLB();
				// Set the list management action
				var action = 'remove';
				// Set the RemoveID value from the passed in cbIDlist
				var removeID = "";
				if ( cbValues.hasOwnProperty("cbIDlist") )
					removeID = cbValues.cbIDlist;
	
				// Update the arguments.fieldName field with the new UUID
				var currFieldVal = jQuery("input[name=#arguments.fieldName#]").val();
	
				// load the initial list items based on the top terms from the chosen facet
				jQuery.get( "#application.ADF.ajaxProxy#",{
					bean: "#rbService#",
					method: 'listManagement',
					currList: currFieldVal,
					currItem: removeID,
					actionType: action
				},
				function(data){
					// Set the value back into the save field
					jQuery("input[name=#arguments.fieldName#]").val(data);
					// Reload the recurrence properties
					renderRecurrence_#arguments.fieldName#();
				});
			}
	
	
			/****************************/
			/*    UI Button Functions   */
			/****************************/
	
			// Function to open lightboxed form to delete recurrence from the trash can icon
			function removeRecurrenceItem_#arguments.fieldName#(recurrenceID) {
				openLB("#application.ADF.lightboxProxy#?bean=#rbForm#&method=renderRecurrenceDeleteForm&recurrenceID=" + recurrenceID + "&callback=remove_cbFunct_#arguments.fieldName#&cbIDlist=" + recurrenceID + "&title=Delete Recurrence Properties");
			}
			// Function to open lightboxed HTML form to add event recurrence
			function addRecurrence_#arguments.fieldName#() {
				var eventID = jQuery("##calEventID").val();
				<cfif len(trim(newDefaultPickerDate))>
				openLB("#application.ADF.lightboxProxy#?bean=#rbForm#&method=renderRecurrenceHTMLForm&eventid=" + eventID + "&title=Add Recurrence Properties&callback=addEditRecurrence_cbFunct_#arguments.fieldName#&defaultDate=#newDefaultPickerDate#");
				<cfelse>
				openLB("#application.ADF.lightboxProxy#?bean=#rbForm#&method=renderRecurrenceHTMLForm&eventid=" + eventID + "&title=Add Recurrence Properties&callback=addEditRecurrence_cbFunct_#arguments.fieldName#");
				</cfif>
			}
			// Function to open lightboxed form to edit recurrence from the edit recurrence button
			function editRecurrence_#arguments.fieldName#() {
				var eventID = jQuery("##calEventID").val();
				var recurrenceID = jQuery("input[name=#arguments.fieldName#]").val();
				openLB("#application.ADF.lightboxProxy#?bean=#rbForm#&method=renderRecurrenceHTMLForm&recurrenceID=" + recurrenceID + "&eventid=" + eventID + "&callback=addEditRecurrence_cbFunct_#arguments.fieldName#&title=Edit Recurrence Properties");
			}
		</script>
	
		<div class="recurrence-builder-block">
			<!--- // LB Form Button --->
			<div id="addRecurrenceLink_#arguments.fieldName#" class="ui-button ui-state-default ui-corner-all">#params.btnAddText#</div>
			<div id="editRecurrenceLink_#arguments.fieldName#" class="ui-button ui-state-default ui-corner-all" style="display: none;">#params.btnEditText#</div>
			<div style="clear: both;"></div>
			<!--- // DIV where recurrence properties are loaded --->
			<div id="display_#arguments.fieldName#"></div>
			<!--- hidden field to store the value --->
			<input type="hidden" name="#arguments.fieldName#" value="#arguments.value#" id="#params.fieldID#" class="#params.fieldClass#" size="40">
		</div>
	</cfoutput>
</cffunction>
	
	
<cfscript>
	/*private string function getValidationMsg()
	{
		if (arguments.parameters.bindRequired EQ 'one' AND len(arguments.parameters.recurrFieldID))
			return "Please add a Date/Time entry or\nset-up Recurrence Properties.";
		return "Please add a Date/Time entry.";
	}*/

	private struct function setParamDefaults(required string fieldName, required struct parameters)
	{
		var params = arguments.parameters;
		if ( NOT StructKeyExists(params, "fieldID") )
			params.fieldID = arguments.fieldName;
		if ( (NOT StructKeyExists(params, "fieldClass")) OR ( len(trim(params.fieldClass)) LTE 0) )
			params.fieldClass = "";
		if ( (NOT StructKeyExists(params, "btnAddText")) OR ( len(trim(params.btnAddText)) LTE 0) )
			params.btnAddText = "Setup Recurrence";
		if ( (NOT StructKeyExists(params, "btnEditText")) OR ( len(trim(params.btnEditText)) LTE 0) )
			params.btnEditText = "Edit Recurrence";
		return params;
	}

	private boolean function isMultiline()
	{
		return true;
	}

	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery,jQueryUI,ADFLightbox");
	}
	public string function loadResourceDependencies()
	{
		application.ptCalendar.scripts.loadJQuery();
		application.ptCalendar.scripts.loadJQueryUI(themeName=application.ptCalendar.getUItheme());
		application.ptCalendar.scripts.loadADFLightbox();
	}
</cfscript>
</cfcomponent>
